.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.segment.avdrive:

==========
 AV-Drive
==========

* DataModule and support code: :py:mod:`.data.segment.avdrive`
* Splits: **Currently, no splits defined.**
